# -*- coding: utf-8 -*-

from PyQt4 import QtCore
from gui.mainwindow import MainWindow
from model.displayfile import DisplayFile
from model.window import Window
from model.shapes import Point, Line, Polygon, Curve

displayFile = DisplayFile()
mainWindow = MainWindow()
window = Window(mainWindow.ui.canvas, displayFile)

mainWindow.setListModel(displayFile)

QtCore.QObject.connect(displayFile, QtCore.SIGNAL("dataChanged(QModelIndex, QModelIndex)"), window.redraw)
QtCore.QObject.connect(displayFile, QtCore.SIGNAL("transformationOcurred"), window.redraw)

# first time drawn
window.redraw()

def addPoint(pair, name):
	addedPoint = Point(name, pair)
	displayFile.addShape(addedPoint)

def addLine(pairA, pairB, name):
	addedLine = Line(name, pairA, pairB)
	displayFile.addShape(addedLine)

def addBezier(coords, name):
	addedCurve = Curve(name, coords)
	displayFile.addShape(addedCurve)

def addPolygon(pairs, name):
	addedPolygon = Polygon(name, pairs)
	displayFile.addShape(addedPolygon)

def zoom(ratio):
	window.zoom(ratio)

def verticalMove(delta):
	window.move( (0,delta) )

def horizontalMove(delta):
	window.move( (delta,0) )

def removeObjects(objectNames):
	displayFile.removeShapes(objectNames)

def translateObjects(objectNames, vector):
	displayFile.translateObjects(objectNames, vector, window.vupAngle)

def scaleObjects(objectNames, factors):
	displayFile.scaleObjects(objectNames, factors)

def rotateObjects(objectNames, angle, pivot = None):
	displayFile.rotateObjects(objectNames, angle, pivot)

def colorizeObjects(objectIndexes, color):
	itemNames = []
	for i in objectIndexes:
		itemNames.append(i.data().toString())
	displayFile.colorizeObjects(itemNames, color.red(), color.green(), color.blue())

def rotateWindow(angle):
	window.rotate(angle)

def getWindowAngle():
	return window.vupAngle
