# -*- coding: utf-8 -*-

from PyQt4.QtCore import SIGNAL, QAbstractListModel, QModelIndex,  QVariant,  Qt
from shapes import Line, Curve
from transform.transforms import translate, scale, rotate, rotatePPC
import mediator

class DisplayFile(QAbstractListModel):
	"""
	Classe reponsável por armazenar os objetos que devem ser desenhados
	na tela. Além de armazenar os objetos, também cuida de recuperá-los
	e aplicar as funções de transformação sobre os mesmos.
	DisplayFile implementa uma QAbstractListModel, possibilitando que a
	mesma seja usada como model em uma QListView.
	"""
	
	def __init__(self,  parent = None):
		super(QAbstractListModel, self).__init__(parent)
		self._shapes = {}
		self._names = []
		self.guidingShapes = []
		self.createGuidingShapes()
	
	def rowCount(self, parent = QModelIndex()):
		return len(self._names)

	def flags(self,  index):
		return Qt.ItemIsEnabled | Qt.ItemIsSelectable

	def data(self, index, role):
		if not index.isValid():
			return QVariant()
		if index.row() >= len(self._shapes):
			return QVariant()
		if role == Qt.DisplayRole:
			return QVariant( self._names[index.row()] )
		else:
			return QVariant()

	def createGuidingShapes(self):
		self.guidingShapes.append( Line("xAxis", (0,-5000), (0,5000), (0,0,255) ) )
		self.guidingShapes.append( Line("yAxis", (-5000,0), (5000,0), (0,0,255) ) )

	def addShape(self, s):
		rotatePPC(s, -mediator.getWindowAngle(), s.center)
		last = self.rowCount()
		self._shapes[s.name] = s
		
		self.beginInsertRows(QModelIndex(), len(self._names), len(self._names)+1);
		self._names.append(s.name)
		self.endInsertRows()
		
		self.emit(SIGNAL("dataChanged(QModelIndex, QModelIndex)"), self.index(0), self.index(len(self._shapes)))

	def removeShapes(self, objectNames):
		for obj in objectNames:
			del self._shapes[obj]
			self._names.remove(obj)
		self.emit(SIGNAL("dataChanged(QModelIndex, QModelIndex)"), self.index(0), self.index(len(self._shapes)))

	@property
	def shapes(self):
		return self.guidingShapes + self._shapes.values()

	def translateObjects(self, objectNames, vector, vupangle = 0):
		map(lambda name: translate(self._shapes[name], vector, vupangle), objectNames)
		self.emit(SIGNAL("transformationOcurred"))

	def scaleObjects(self, objectNames, factors):
		map(lambda name: scale(self._shapes[name], factors), objectNames)
		self.emit(SIGNAL("transformationOcurred"))

	def rotateObjects(self, objectNames, angle, pivot = None):
		map(lambda name: rotate(self._shapes[name], angle, pivot), objectNames)
		self.emit(SIGNAL("transformationOcurred"))

	def rotateAllObjectsPPC(self, angle, pivot):
		map(lambda obj: rotatePPC(obj, angle, pivot), self.shapes)
		self.emit(SIGNAL("transformationOcurred"))

	def colorizeObjects(self, objectNames, r, g, b):
		for name in objectNames:
			self._shapes[name].color = (r,g,b)
		self.emit(SIGNAL("transformationOcurred"))
