# -*- coding: utf-8 -*-

import sys
sys.path.append("..")

import unittest
from model.shapes import Polygon
from transform.clipper import clipLine

class ClipperTest(unittest.TestCase):
	"""
	Tests relating to the Line clipping
	"""
	
	def setUp(self):
		self.wmin = (-50,-50)
		self.wmax = (50,50)
	
	def testClippingLineTotallyOutsideAndParallelToY(self):
		"""
		A Line totally outside and parallel to the y-axis don't pass
		"""
		self.assertEqual(None, clipLine((-60,-60), (-60, 60),self.wmin,self.wmax) )
		
	def testClippingLineTotallyOutsideParallelToX(self):
		"""
		A Line totally outside and parallel to the x-axis don't pass
		"""
		self.assertEqual(None, clipLine((-55,-55), (40,-55),self.wmin,self.wmax) )
		
	def testClippingLineTotallyOutsideDiagonal(self):
		"""
		A diagonal Line totally outside the clipping window
		"""
		self.assertEqual(None, clipLine((0,-150), (150,0),self.wmin,self.wmax) )
		
	def testClippingLineTotallyInsideWindowParallelToY(self):
		"""
		A Line totally inside and parallel to the y-axis pass unchanged
		"""
		self.assertEqual(((40,-30),(40,30)), clipLine((40,-30), (40,30),self.wmin,self.wmax) )
		
	def testClippingLineTotallyInsideParallelToX(self):
		"""
		A Line totally inside and parallel to the x-axis pass unchanged
		"""
		self.assertEqual(((-10,-40),(40,-40)), clipLine((-10,-40),(40,-40),self.wmin,self.wmax) )
		
	def testClippingLineTotallyInsideDiagonal(self):
		"""
		A Line totally inside and diagonal
		"""
		self.assertEqual(((-20,14),(10,15)), clipLine((-20,14), (10,15),self.wmin,self.wmax) )
		
	def testClippingLinePartiallyInsideTwiceParallelToY(self):
		"""
		A Line partially inside, parallel to y and crossing the window twice
		"""
		self.assertEqual(((40,-50),(40,50)), clipLine((40,-80), (40,80),self.wmin,self.wmax) )
		
	def testClippingLinePartiallyInsideTwiceParallelToX(self):
		"""
		A Line partially inside, parallel to x and crossing the window twice
		"""
		self.assertEqual(((-50,-20),(50,-20)), clipLine((-70,-20),(70,-20),self.wmin,self.wmax) )
		
	def testClippingLinePartiallyInsideOnceParallelToY(self):
		"""
		A Line partially inside, parallel to y and crossing the window once
		"""
		self.assertEqual(((40,-50),(40,40)), clipLine((40,-80), (40,40),self.wmin,self.wmax) )
		
	def testClippingLinePartiallyInsideOnceParallelToX(self):
		"""
		A Line partially inside, parallel to x and crossing the window once
		"""
		self.assertEqual(((-40,-20),(50,-20)), clipLine((-40,-20),(70,-20),self.wmin,self.wmax) )

if __name__ == "__main__":
    unittest.main()
