# coding: utf-8

import sys
sys.path.append("..")

import unittest
from model.shapes import Point, Line, Polygon

class PointTest(unittest.TestCase):
    """
    Tests related to Points.
    """

    def testPointCreation(self):
        """
        Point creation.
        """
        p = Point("ponto", (0,0))
        self.assertEqual(p.name, "ponto")
        self.assertEqual(p.coords, [(0,0)])
        self.assertEqual(p.color, (0,0,0))
        
    def testPointEquality(self):
    	"""
    	Point equality and inequality.
    	"""
    	
    	p1 = Point("ponto1", (23,1))
    	p2 = Point("ponto1", (23,1))
    	p3 = Point("ponto3", (42,42))
    	
    	self.assertEqual(p1,p2)
    	self.assert_(not (p1 == p3))
    	
    	self.assert_(p1 != p3)
    	self.assert_(not (p1 != p2))

    def testCenterEqualsCoordinates(self):
        """
        Point center should be equal to the coordinates.
        """
        p = Point("ponto", (10,10))
        self.assertEqual(p.center, p.coords[0])

class LineTest(unittest.TestCase):
    """
    Tests related to Lines.
    """

    def testLineCreation(self):
        """
        Line Creation.
        """
        l = Line("line", (0,0), (10,10))
        self.assertEqual(l.name, "line")
        self.assertEqual(l.coords, [(0,0), (10,10)])
        self.assertEqual(l.color, (0,0,0))

    def testCenter(self):
        """
        Center should be the average of the x's  and y's
        """
        l = Line("line", (0,0), (10,10))
        self.assertEqual(l.center, (5,5))
        
    def testLineEquality(self):
    	"""
    	Line equality and inequality.
    	"""
    	
    	l1 = Line("linha1", (-100,-100), (100,100))
    	l2 = Line("linha2", (-100,-100), (100,100))
    	l3 = Line("linha3", (0,0), (42,1))
    	
    	self.assertEqual(l1,l2)
    	self.assert_(not (l1 == l3))
    	
    	self.assert_(l1 != l3)
    	self.assert_(not (l1 != l2))
    	
class PolygonTest(unittest.TestCase):
	"""
	Tests related to Polygons
	"""
	
	def testPolygonCreation(self):
		"""
		Polygon creation.
		"""
		
		square = Polygon("quadrado", [(-50,-50), (50,-50), (50,50), (-50,50)])
		self.assertEqual(square.name, "quadrado")
		self.assertEqual(square.coords[:-1], [(-50,-50), (50,-50), (50,50), (-50,50)])
		self.assertEqual(square.color, (0,0,0))
		
	def testPolygonCenter(self):
		"""
		Polygon center. Is the average of the respective coordinates in all points
		"""
		isoTriangle = Polygon("trianguloIsosceles", [(-50,-50), (0,100), (50,-50)])
		self.assertEqual(isoTriangle.center, (0,0))
		
	def testPolygonEquality(self):
		"""
		Polygon equality and inequality
		"""
		
		pol1 = Polygon("tri1", [(-100,-100), (0,200), (100,-100)])
		pol2 = Polygon("tri2", [(-100,-100), (0,200), (100,-100)])
		pol3 = Polygon("quad1", [(-50,-50), (50,-50), (50,50), (-50,50)])
		
		self.assertEqual(pol1,pol2)
		self.assert_(not (pol1 == pol3))
		
		self.assert_(pol1 != pol3)
		self.assert_(not (pol1 != pol2))
		

if __name__ == "__main__":
    unittest.main()
