# coding: utf-8

import sys
sys.path.append("..")

import unittest
from model import shapes
from transform import transforms

class TestScale(unittest.TestCase):
	"""
	Tests of the scaling linear transform.
	"""
	
	def testScaleSquareInTheOrigin(self):
		"""
		A square centered in the origin being enlarged by two
		"""
		tested = shapes.Polygon("", [(-5,-5), (5,-5), (5,5), (-5,5)])
		expected = shapes.Polygon("", [(-10,-10), (10,-10), (10,10), (-10,10)])
		
		transforms.scale(tested, (2.0,2.0))
		self.assertEqual(expected, tested)
		
	def testScaleSquareInTheOriginNOT(self):
		"""
		A square with its center far from the origin being shrinked by half
		"""
		tested = shapes.Polygon("", [(50,50), (150,50), (150,150), (50,150)])
		expected = shapes.Polygon("", [(75,75), (125,75), (125,125), (75,125)])
		
		transforms.scale(tested, (0.5,0.5))
		self.assertEqual(expected, tested)

class TestTranslate(unittest.TestCase):
	"""
	Tests of the translating linear transform
	"""
	
	def testTranslatePoint(self):
		"""
		Translating a point
		"""
		tested = shapes.Point("", (20,20))
		expected = shapes.Point("", (46,32))
		
		transforms.translate(tested, (26,12))
		self.assertEqual(expected, tested)
		
	def testTranslatePolygon(self):
		"""
		To translate a Polygon is to translate all of its points by the same vector
		"""
		tested = shapes.Polygon("", [(-50,-50), (0,100), (50,-50)])
		expected = shapes.Polygon("", [(-44,-44), (6,106), (56,-44)])
		
		transforms.translate(tested, (6,6))
		self.assertEqual(expected, tested)

class TestRotate(unittest.TestCase):
    pass

class TestRotatePPC(unittest.TestCase):
    pass

class TestViewPortTrasnformation(unittest.TestCase):
    pass

if __name__ == "__main__":
    unittest.main()
