# -*- encoding: utf8 -*-

from math import sin, cos
from numpy import matrix

class Transform(object):
	"""
	Classe base de todas as transformações de objetos. Uma numpy.matrix 
	é responsável pela transformação, e pode ser combinada com a operação 
	de multiplicação.
	"""
	def __init__(self, matrix):
		"""Armazena a matrix de transformação."""
		self._matrix = matrix

	def __mul__(self, other):
		"""Combina duas transdormaçõs, retornando uma nova com as matrizes multiplicadas."""
		return Transform(self.matrix * other.matrix)
	
	def __call__(self, vector):
		"""Executa uma transformação em um vetor."""
		l = matrix(list(vector) + [1.0])
		r = l * self.matrix
		return tuple(r.tolist()[0][:-1])

	@property
	def matrix(self):
		"""Retorna a matrix armazenada na transformação."""
		return self._matrix

class Translate2D(Transform):
	def __init__(self, vector):
		m = matrix([[1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [float(vector[0]), float(vector[1]), 1.0]])
		Transform.__init__(self, m)

class Scale2D(Transform):
	def __init__(self, factors):
		m = matrix([[factors[0], 0.0, 0.0], [0.0, factors[1], 0.0], [0.0, 0.0, 1.0]])
		Transform.__init__(self, m)

class Rotate2D(Transform):
	def __init__(self, t):
		sin_, cos_ = sin(t), cos(t)
		m = matrix([[cos_, sin_, 0.0], [-sin_, cos_, 0.0], [0.0, 0.0, 1.0]])
		Transform.__init__(self, m)
