# -*- coding: utf-8 -*-

from math import radians
from transform.matrices import Translate2D, Scale2D, Rotate2D

canvas_size = 460

def translate(shape, vector, vupangle = 0):
	r = Rotate2D(radians(-vupangle))
	rotatedVector = r(vector)
	
	translationForWc = Translate2D(vector)
	translationForPPC = Translate2D(rotatedVector)

	shape.applyTransform(translationForWc)
	shape.applyToPPC(translationForPPC)

def scale(shape, factors):
	cx, cy = map(float, shape.center)	
	toOrigin = Translate2D( (-cx, -cy) )
	scaling = Scale2D(factors)
	fromOrigin = Translate2D( (cx, cy) )

	totalTransform = (toOrigin * scaling) * fromOrigin

	shape.applyTransform(totalTransform)
	shape.applyToPPC(totalTransform)

def rotate(shape, angle, pivot = None):
	tehta = radians(angle)
	pivot = shape.center if (pivot == None) else pivot
	
	cx, cy = map(float, pivot)
	toOrigin = Translate2D( (-cx, -cy) )
	rotating = Rotate2D(tehta)
	fromOrigin = Translate2D( (cx, cy) )

	totalTransform = (toOrigin * rotating) * fromOrigin

	shape.applyTransform(totalTransform)
	shape.applyToPPC(totalTransform)

def rotatePPC(shape, angle, pivot = None):
	tehta = radians(angle)
	pivot = shape.center if (pivot == None) else pivot

	cx, cy = map(float, pivot)
	toOrigin = Translate2D( (-cx, -cy) )
	rotating = Rotate2D(tehta)
	fromOrigin = Translate2D( (cx, cy) )

	totalTransform = (toOrigin * rotating) * fromOrigin
	shape.applyToPPC(totalTransform)

def viewportTransform(pair, wmin, wmax):
	xt = ((pair[0] - wmin[0]) / float(wmax[0] - wmin[0])) * canvas_size
	yt = (1 - ((pair[1] - wmin[1]) / float(wmax[1] - wmin[1]))) * canvas_size
	return (xt, yt)
